@@ -8,7 +8,7 @@
 #	    All rights reserved
 #
 # Created: Sat 30 Jan 2010 20:16:55 EET too
-# Last modified: Mon 22 Feb 2010 00:22:02 EET too
+# Last modified: Thu 25 Feb 2010 22:00:19 EET too
 
 use strict;
 use warnings;
@@ -24,7 +24,7 @@ my (@table, $pmx, $pmy, $pmv);
 sub init_puzzle() 
 {
     ($pmx, $pmy, $pmv) = ( 9, 9, undef ); # old multi accidentaly overwritten.
-
+    @table = ();
     push @table, [ 0, 0, 0,  0, 0, 0,  0, 0, 0 ] for (1..9);
 
 }
@@ -33,13 +33,14 @@ sub init_puzzle()
 
 sub read_puzzle()
 {
+    init_puzzle;
     open I, '<', "$ENV{HOME}/.config/thumb_sudoku.data" or return 0;
     $_ = <I>;
     return 0 unless /^thumb sudoku data format 1\s/;
 
-    print 123, "\n";
     sub asp($) {
-	my @a = split '', $_[0];
+	my @a = ( '', '', '', '', '', '', '', '', '', 0 );
+	foreach (split '', $_[0]) { $a[$_ - 1] = $_ + 0 if $_ > 0; }
 	return \@a;
     }
     while (<I>) {
@@ -70,8 +71,9 @@ sub read_puzzle()
 
 sub gen_puzzle()
 {
+    init_puzzle;
     open I, '<', 'precalc' or die;
-    my $line = int (rand 1000);
+    my $line = int (rand 1000) + 1;
     while (<I>)
     {
 	chomp ($line = $_), last if $. == $line;
@@ -103,7 +105,6 @@ sub send_puzzle()
     print "@list\n";
 }
 
-init_puzzle;
 read_puzzle or gen_puzzle;
 send_puzzle;
 print "*$pbx$pby", $pbs? '.': '+', "\n";
@@ -192,7 +193,6 @@ while (<STDIN>) {
     }
     if ($w eq '@') { # new game
 	print "@\n";
-	init_puzzle;
 	gen_puzzle;
 	send_puzzle;
 	print "*$pbx$pby", $pbs? '.': '+', "\n";
